import { Request, Response } from "express";
import CheckIn from "../db/models/CheckIn";
import Boat from "../db/models/Boat";

//create log entry
const createLogEntryController = async (req: Request, res: Response) => {
  try {
    const logEntry = req.body;
    const boatid = await Boat.findByPk(logEntry.boatID);

    //get status of boat
    const bootAvailability = boatid.status;

    //if boat is not available => it's locked
    if (bootAvailability === false) {
      return res.status(409).json({ success: false, error: "BoatLocked" });
    }

    const newLogEntry = await CheckIn.create(logEntry);

    return res.status(201).json({
      success: true,
      result: {
        startTime: newLogEntry.startTime,
        estimatedEndTime: newLogEntry.estimatedEndTime,
        email: newLogEntry.email,
        firstName: newLogEntry.firstName,
        lastName: newLogEntry.lastName,
        additionalClients: newLogEntry.additionalClients,
        boatID: newLogEntry.boatID,
      },
    });
  } catch (error) {
    console.error(error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};
export default createLogEntryController;
