import { Router } from "express";
import { body } from "express-validator";
import validateToken from "../middleware/validateToken";
import boatControllers from "../controllers/boatControllers.controllers";
import handleValidationResult from "../middleware/handleValidationResult";

const boatsRouter = Router();

//show all boats
boatsRouter.get("/api/boat/", boatControllers.showAllBoatsController);

//show boat by given id
boatsRouter.get("/api/boat/:id", boatControllers.showBoatById);

//delete a boat
boatsRouter.delete(
  "/api/boat/:id",
  validateToken,
  boatControllers.deleteBoatById
);

//create boat
boatsRouter.post(
  "/api/boat/",
  body("name").not().isEmpty(),
  body("boattype").not().isEmpty(),
  body("status").not().isEmpty() && body("status").isIn([1, 0]),
  body("tags").not().isEmpty() && body("tags").isArray(),
  handleValidationResult,
  validateToken,
  boatControllers.createBoat
);

export default boatsRouter;
