import { Router } from "express";
import validateToken from "../middleware/validateToken";
import userControllers from "../controllers/userControllers.controllers";
import handleValidationResult from "../middleware/handleValidationResult";
import { body } from "express-validator";


const userRouter = Router();

userRouter.get(
  "/api/user/",
  validateToken,
  userControllers.showCurrentUserController
);

userRouter.patch(
  "/api/user/",
  body("first_name").not().isEmpty(),
  body("last_name").not().isEmpty(),
  body("email").isEmail().normalizeEmail(),
  body("role").isIn(["coordinator", "boatManager"]),
  body("password").isLength({ min: 6 }),
  handleValidationResult,
  validateToken,
  userControllers.updateCurrentUser
);

export default userRouter;
